==> owlapi-oboformat-3.5.1-sources.jar: org/coode/owlapi/obo12/parser/OBOTagValuePair.java <==
/*
 * This file is part of the OWL API.
 *  
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *  
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *  
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *  
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, The University of Manchester
 *  
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *  
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.coode.owlapi.obo12.parser;

/**
 * Author: Matthew Horridge<br>
 * Stanford University<br>
 * Bio-Medical Informatics Research Group<br>
 * Date: 19/04/2012
 */
@SuppressWarnings("all")
class OBOTagValuePair {

    private String tagName;
    private String value;
    private String qualifier;
    private String comment;

    /**
     * @param tagName
     * @param value
     * @param qualifier
     * @param comment
     */
    public OBOTagValuePair(String tagName, String value, String qualifier,
            String comment) {
        this.tagName = tagName;
        this.value = value;
        this.qualifier = qualifier;
        this.comment = comment;
    }

    /** @return the tag name */
    public String getTagName() {
        return tagName;
    }

    /** @return the value */
    public String getValue() {
        return value;
    }

    /** @return the qualifier */
    public String getQualifier() {
        return qualifier;
    }

    /** @return the comment */
    public String getComment() {
        return comment;
    }
}

==> owlapi-oboformat-3.5.2-sources.jar: org/coode/owlapi/obo12/parser/OBOTagValuePair.java <==
/*
 * This file is part of the OWL API.
 *  
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *  
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *  
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *  
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, The University of Manchester
 *  
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *  
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.coode.owlapi.obo12.parser;


/**
 * Author: Matthew Horridge<br>
 * Stanford University<br>
 * Bio-Medical Informatics Research Group<br>
 * Date: 19/04/2012
 */
@SuppressWarnings("all")
class OBOTagValuePair {

    
    private String tagName;
    
    private String value;
    
    private String qualifier;
    
    private String comment;

    /**
     * @param tagName
     * @param value
     * @param qualifier
     * @param comment
     */
    public OBOTagValuePair( String tagName,  String value,
             String qualifier,  String comment) {
        this.tagName = tagName;
        this.value = value;
        this.qualifier = qualifier;
        this.comment = comment;
    }

    /** @return the tag name */
    
    public String getTagName() {
        return tagName;
    }

    /** @return the value */
    
    public String getValue() {
        return value;
    }

    /** @return the qualifier */
    
    public String getQualifier() {
        return qualifier;
    }

    /** @return the comment */
    
    public String getComment() {
        return comment;
    }
}
